const displayToast = (window as any).displayToast as (messageType: string, message:string) => void;

function createLoadOverlay(): HTMLDivElement {
    const div = document.createElement('div');
    div.classList.add('overlay', 'dark');
    const i = document.createElement('i');
    i.classList.add('fas', 'fa-3x', 'fa-spinner', 'fa-spin');
    div.appendChild(i);

    return div;
}

$(".modal-file").each(function () {
    const modal = this;
    const confirmButton = this.querySelector(".modal-confirm") as HTMLButtonElement;
    const url = modal.dataset.url;
    confirmButton.addEventListener('click', ()=> {
        // Create custom Modal
        const overlay = createLoadOverlay();
        confirmButton.appendChild(overlay);
        confirmButton.disabled = true;
        $.ajax({
            "type": "PUT",
            "timeout": 10000, // 10 seconds
            "url": url,
            "success": () => {
                displayToast("success","Preuve Valider!!");
                setTimeout(()=>location.reload(), 1000);
            },
            "error": () => {
                displayToast("error","Une erreur est survenue ! Veuillez réessayer ultérieurement.");
            },
            "complete": () => {
                confirmButton.removeChild(overlay);
                if (modal) {
                    ($(modal) as any).modal('hide');
                }
                confirmButton.disabled = false;
            }
        })
    });
});

$('.modal-classic').on('show.bs.modal', function (event: any) {
    const button = $(event.relatedTarget); // Button that triggered the modal
    
    const url = button.data('url'); // Extract info from data-* attributes
    const params = button.data('params');
    const callbackText = button.data('callback-text');

    const body = button.data('body');
    // If necessary, you could initiate an AJAX request here (and then do the updating in a callback).
    // Update the modal's content. We'll use jQuery here, but you could use a data binding library or other methods instead.
    const modal = this as HTMLDivElement;

    if (modal) {        
        const confirmButton = modal.querySelector(".modal-confirm") as HTMLButtonElement;

        $(confirmButton).off();

        // Git blame : Romain was there

        if (body) {
            (modal.querySelector('.modal-body') as HTMLDivElement).innerText = body;
        }
        
        if (url && callbackText) {
            $(confirmButton).on('click', ()=> {
                const overlay = createLoadOverlay();
                confirmButton.appendChild(overlay);
                confirmButton.disabled = true;
                $.ajax({
                    "type": "PUT",
                    "url": url,
                    "data": JSON.stringify(params),
                    "success": () => {
                        displayToast("success",callbackText);
                    },
                    "error": () => {
                        displayToast("error","Une erreur est survenue ! Veuillez réessayer ultérieurement.");
                    },
                    "complete": () => {
                        confirmButton.removeChild(overlay);
                        ($(modal) as any).modal('hide');
                        confirmButton.disabled = false;
                        setTimeout(() => location.reload(), 1000);
                    },
                    "dataType": "json",
                    'contentType': 'application/json'
                });
            });
        }
    }
});

$(".modal-file-delete").each(function () {
    const modal = this;
    const confirmButton = this.querySelector(".modal-confirm") as HTMLButtonElement;
    const url = modal.dataset.url;
    confirmButton.addEventListener('click', ()=> {
        // Create custom Modal
        const overlay = createLoadOverlay();
        confirmButton.appendChild(overlay);
        confirmButton.disabled = true;
        $.ajax({
            "type": "DELETE",
            "timeout": 10000, // 10 seconds
            "url": url,
            "success": () => {
                displayToast("success","Preuve supprimée!!");
                setTimeout(()=>location.reload(), 1000);
            },
            "error": () => {
                displayToast("error","Une erreur est survenue ! Veuillez réessayer ultérieurement.");
            },
            "complete": () => {
                confirmButton.removeChild(overlay);
                if (modal) {
                    ($(modal) as any).modal('hide');
                }
                confirmButton.disabled = false;
            }
        })
    });
});
