const Encore = require('@symfony/webpack-encore');

// Manually configure the runtime environment if not already configured yet by the "encore" command.
// It's useful when you use tools that rely on webpack.config.js file.
if (!Encore.isRuntimeEnvironmentConfigured()) {
    Encore.configureRuntimeEnvironment(process.env.NODE_ENV || 'dev');
}

Encore
    .autoProvidejQuery()
    .autoProvideVariables({
        moment:'moment',
    })
    .addAliases({jQuery: 'jquery'})
    // directory where compiled assets will be stored
    .setOutputPath('public/build/')
    // public path used by the web server to access the output path
    .setPublicPath('/build')
    // only needed for CDN's or sub-directory deploy
    //.setManifestKeyPrefix('build/')

    /*
     * ENTRY CONFIG
     *
     * Each entry will result in one JavaScript file (e.g. app.js)
     * and one CSS file (e.g. app.css) if your JavaScript imports CSS.
     */
    .addEntry('base', ['./assets/ts/base.ts', './assets/ts/darkmode.ts', './assets/styles/base.scss'])
    .addEntry('home', ['./assets/ts/home.ts', './assets/styles/home.scss'])
    .addEntry('admin', ['./assets/styles/admin.scss'])
    .addEntry('adminHome', ['./assets/ts/adminHome.ts'])
    .addEntry('adminConfig', ['./assets/ts/adminConfig.ts'])
    .addEntry('newRequest', ['./assets/ts/newRequest.ts', './assets/styles/newRequest.scss'])
    .addEntry('modal', ['./assets/ts/modal.ts'])
    .addEntry('siteConfig', ['./assets/ts/adminSiteConfig.ts'])
    .addEntry('maps', ['./assets/ts/maps.ts', './assets/styles/maps.scss'])

    .copyFiles({
        from: './assets/images',
        to: 'images/[path][name].[ext]'
    })

    // Copy Admin-LTE images from npm stuff
    .copyFiles({
        from: './node_modules/admin-lte/dist/img',
        to: 'images/[path][name].[ext]'
    })
    .copyFiles({
        from: './node_modules/leaflet/dist/images',
        to: 'images/[path][name].[ext]'
    })
    .copyFiles({
        from: './node_modules/leaflet/src/images',
        to: 'images/[path][name].[ext]'
    })

    /*
     * FEATURE CONFIG
     *
     * Enable & configure other features below. For a full
     * list of features, see:
     * https://symfony.com/doc/current/frontend.html#adding-more-features
     */

    // When enabled, Webpack "splits" your files into smaller pieces for greater optimization.
    .splitEntryChunks()

    // will require an extra script tag for runtime.js
    // but, you probably want this, unless you're building a single-page app
    .enableSingleRuntimeChunk()

    // Stimulus
    .enableStimulusBridge('./assets/controllers.json')
    
    // Enable Sass loader
    .enableSassLoader()
    
    .enableTypeScriptLoader()
    .enableForkedTypeScriptTypesChecking()
    .cleanupOutputBeforeBuild()
    .enableBuildNotifications()
    .enableSourceMaps(!Encore.isProduction() || process.env.GENERATE_SOURCE_MAP == '1')
    // enables hashed filenames (e.g. app.abc123.css)
    .enableVersioning(Encore.isProduction())

    .configureBabel((config) => {
        config.plugins.push('@babel/plugin-proposal-class-properties');
    })

    // enables @babel/preset-env polyfills
    .configureBabelPresetEnv((config) => {
        config.useBuiltIns = 'usage';
        config.corejs = 3;
    });

module.exports = Encore.getWebpackConfig();
